 -- Import the lib use.
modimport("libs/env.lua")

-- Actions Initialization.
use "data/actions/init"

-- Component Initialization.
use "data/components/init"

PrefabFiles = {
	"bav",
	"acefire",
	"minalinsky",
	"foxball",
	"coffee",
	"conch",
}

Assets = {
    Asset( "IMAGE", "images/saveslot_portraits/bav.tex" ),
    Asset( "ATLAS", "images/saveslot_portraits/bav.xml" ),

    Asset( "IMAGE", "images/selectscreen_portraits/bav.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/bav.xml" ),
	
    Asset( "IMAGE", "images/selectscreen_portraits/bav_silho.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/bav_silho.xml" ),

    Asset( "IMAGE", "bigportraits/bav.tex" ),
    Asset( "ATLAS", "bigportraits/bav.xml" ),
	
	Asset( "IMAGE", "images/map_icons/bav.tex" ),
	Asset( "ATLAS", "images/map_icons/bav.xml" ),
	
	Asset( "ATLAS", "images/hud/bavtab.xml" ),
	
	Asset( "IMAGE", "images/inventoryimages/acefire.tex" ),
	Asset( "ATLAS", "images/inventoryimages/acefire.xml" ),
	
	Asset( "IMAGE", "images/inventoryimages/minalinsky.tex" ),
	Asset( "ATLAS", "images/inventoryimages/minalinsky.xml" ),
	
	Asset( "IMAGE", "images/inventoryimages/foxball.tex" ),
	Asset( "ATLAS", "images/inventoryimages/foxball.xml" ),
	
	Asset( "IMAGE", "images/inventoryimages/coffee.tex" ),
	Asset( "ATLAS", "images/inventoryimages/coffee.xml" ),
	
	Asset( "IMAGE", "images/inventoryimages/conch.tex" ),
	Asset( "ATLAS", "images/inventoryimages/conch.xml" ),
	
	Asset( "IMAGE", "images/avatars/avatar_bav.tex" ),
    Asset( "ATLAS", "images/avatars/avatar_bav.xml" ),
	
	Asset( "ATLAS", "images/avatars/self_inspect_bav.xml" ),
	
	Asset( "IMAGE", "images/avatars/avatar_ghost_bav.tex" ),
    Asset( "ATLAS", "images/avatars/avatar_ghost_bav.xml" ),

}

local require = GLOBAL.require
local STRINGS = GLOBAL.STRINGS

local COOK = GLOBAL.ACTIONS.COOK
local old_cook_fn = COOK.fn

local resolvefilepath = GLOBAL.resolvefilepath

local Ingredient = GLOBAL.Ingredient
local RECIPETABS = GLOBAL.RECIPETABS
local Recipe = GLOBAL.Recipe
local TECH = GLOBAL.TECH
  
local function RecheckForThreat(inst)
    local busy = inst.sg:HasStateTag("sleeping") or inst.sg:HasStateTag("busy") or inst.sg:HasStateTag("flying")
    if not busy then
        local threat = GLOBAL.FindEntity(inst, 5, nil, nil, {'notarget', 'birdwhisperer'}, {'player', 'monster', 'scarytoprey'})
        return threat ~= nil or GLOBAL.TheWorld.state.isnight
    end
end
 
AddStategraphPostInit("bird", function(sg)
	local old = sg.events.flyaway.fn
	sg.events.flyaway.fn = function(inst)
		if RecheckForThreat(inst) then
			old(inst)
		end
	end
end)

local containers = GLOBAL.require("containers")
local oldwidgetsetup = containers.widgetsetup
containers.widgetsetup = function(container, prefab)
    if not prefab and container.inst.prefab == "minalinsky" then
        prefab = "backpack"
    end
    oldwidgetsetup(container, prefab)
end

COOK.fn = function(act, ...)
    local result = old_cook_fn(act)
    local stewer = act.target.components.stewer
    if result and stewer ~= nil and act.doer.prefab == "bav" then
        local fn = stewer.task.fn
        stewer.task:Cancel()
        fn(act.target, stewer)
    end
end

AddPrefabPostInit("cookpot", function(inst)
    if inst.components.stewer == nil then
        return
    end
    -- using the same harvest logic and repeat the item giving step once
    local old_harvest = inst.components.stewer.Harvest
    inst.components.stewer.Harvest = function(self, harvester)
        if harvester and harvester.prefab == "bav" then
            if self.done and self.product and harvester.components.inventory then
                local loot = GLOBAL.SpawnPrefab(self.product)
                if loot ~= nil then
                    if self.spoiltime ~= nil and loot.components.perishable ~= nil then
                        local spoilpercent = self:GetTimeToSpoil() / self.spoiltime
                        loot.components.perishable:SetPercent(self.product_spoilage * spoilpercent)
                        loot.components.perishable:StartPerishing()
                    end
                    harvester.components.inventory:GiveItem(loot, nil, self.inst:GetPosition())
                end
            end
        end
        return old_harvest(self, harvester)
    end
end)

GLOBAL.STRINGS.NAMES.ACEFIRE = "foxfire 狐火"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.ACEFIRE = "I can find it."
STRINGS.RECIPE_DESC.ACEFIRE = "Long-range weapon\n远程武器."

GLOBAL.STRINGS.NAMES.FOXBALL = "foxball 狐球"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.FOXBALL = "I can find it."
STRINGS.RECIPE_DESC.FOXBALL = "Multi_function tool\n多功能工具."

GLOBAL.STRINGS.NAMES.MINALINSKY = "foxbag 狐裘"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.MINALINSKY = "I can find it."
STRINGS.RECIPE_DESC.MINALINSKY = "Refrigerate food\n冷藏食物."

GLOBAL.STRINGS.NAMES.COFFEE = "coffee 咖啡"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.COFFEE = "Mysterious force."
STRINGS.RECIPE_DESC.COFFEE = "Fill the state\n加满状态."

GLOBAL.STRINGS.NAMES.CONCH = "conch 海螺"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.CONCH = "conch."
STRINGS.RECIPE_DESC.CONCH = "Hypnosis and fertilize \n催眠、避雷和施肥"

--Mini Maps
AddMinimapAtlas("images/inventoryimages/acefire.xml")
AddMinimapAtlas("images/inventoryimages/minalinsky.xml")
AddMinimapAtlas("images/inventoryimages/foxball.xml")
AddMinimapAtlas("images/inventoryimages/coffee.xml")
AddMinimapAtlas("images/inventoryimages/conch.xml")

--Bav Tab

bavtab = AddRecipeTab("Tomoe", 999, "images/hud/bavtab.xml", "bavtab.tex", "bavbuilder")

--custom recipe
AddRecipe("goose_feather", { Ingredient("feather_robin_winter", 2), Ingredient("feather_robin", 2) }, RECIPETABS.DRESS, TECH.NONE)
AddRecipe("dragon_scales", { Ingredient("bearger_fur", 1), Ingredient("goose_feather", 1) }, RECIPETABS.DRESS, TECH.NONE)
AddRecipe("bearger_fur", { Ingredient("beefalowool", 5), Ingredient("pigskin", 5) }, RECIPETABS.DRESS, TECH.NONE)
AddRecipe("deerclops_eyeball", { Ingredient("meat", 5), Ingredient("rabbit", 5) }, RECIPETABS.DRESS, TECH.NONE)

AddRecipe("lightninggoathorn", { Ingredient("horn", 1), Ingredient("goldnugget", 1) }, RECIPETABS.TOWN, TECH.NONE)
AddRecipe("livinglog", { Ingredient("glommerfuel", 1), Ingredient("goldnugget", 1) }, RECIPETABS.TOWN, TECH.NONE)
AddRecipe("manrabbit_tail", { Ingredient("coontail", 1), Ingredient("goldnugget", 1) }, RECIPETABS.TOWN, TECH.NONE)
AddRecipe("minotaurhorn", { Ingredient("horn", 2), Ingredient("goldnugget", 5) }, RECIPETABS.TOWN, TECH.NONE)

AddRecipe("mandrake", { Ingredient("dragonfruit", 1), Ingredient("poop", 5) }, RECIPETABS.FARM, TECH.NONE)
AddRecipe("goatmilk", { Ingredient("ice", 2), Ingredient("meat_dried", 2) }, RECIPETABS.FARM, TECH.NONE)
AddRecipe("tallbirdegg", { Ingredient("bird_egg", 5), Ingredient("smallmeat", 5) }, RECIPETABS.FARM, TECH.NONE)
AddRecipe("butter", { Ingredient("mosquitosack", 1), Ingredient("butterflywings", 1) }, RECIPETABS.FARM, TECH.NONE)
	
AddRecipe("bluegem", { Ingredient("blue_cap", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )
AddRecipe("redgem", { Ingredient("red_cap", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )
AddRecipe("greengem", { Ingredient("green_cap", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )
AddRecipe("yellowgem", { Ingredient("honey", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )
AddRecipe("thulecite", { Ingredient("transistor", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )
AddRecipe("orangegem", { Ingredient("pumpkin", 1), Ingredient("goldnugget", 1) }, RECIPETABS.REFINE, TECH.NONE )

--Bav Recipes

local acefire_recipe = AddRecipe("acefire",
{GLOBAL.Ingredient("spear", 1), GLOBAL.Ingredient("transistor", 1), GLOBAL.Ingredient("nitre", 1)},
bavtab, TECH.NONE,
nil, nil, nil, nil, nil,
"images/inventoryimages/acefire.xml", "acefire.tex")
acefire_recipe.tagneeded = false
acefire_recipe.builder_tag = "bavbuilder"

local foxball_recipe = AddRecipe("foxball",
{GLOBAL.Ingredient("goldenaxe", 1), GLOBAL.Ingredient("goldenshovel", 1),GLOBAL.Ingredient("goldenpickaxe", 1)},
bavtab, TECH.NONE,
nil, nil, nil, nil, nil,
"images/inventoryimages/foxball.xml", "foxball.tex")
foxball_recipe.tagneeded = false
foxball_recipe.builder_tag = "bavbuilder"

local minalinsky_recipe = AddRecipe("minalinsky",
{GLOBAL.Ingredient("beefalowool", 5), GLOBAL.Ingredient("silk", 5), GLOBAL.Ingredient("bluegem", 1)},
bavtab, TECH.NONE,
nil, nil, nil, nil, nil,
"images/inventoryimages/minalinsky.xml", "minalinsky.tex")
minalinsky_recipe.tagneeded = false
minalinsky_recipe.builder_tag = "bavbuilder"

local coffee_recipe = AddRecipe("coffee",
{GLOBAL.Ingredient("ice", 2), GLOBAL.Ingredient("honey", 2), GLOBAL.Ingredient("butter", 1)},
bavtab, TECH.NONE,
nil, nil, nil, nil, nil,
"images/inventoryimages/coffee.xml", "coffee.tex")
coffee_recipe.tagneeded = false
coffee_recipe.builder_tag = "bavbuilder"

local conch_recipe = AddRecipe("conch",
{GLOBAL.Ingredient("panflute", 1), GLOBAL.Ingredient("fertilizer", 1),GLOBAL.Ingredient("purplegem", 1)},
bavtab, TECH.NONE,
nil, nil, nil, nil, nil,
"images/inventoryimages/conch.xml", "conch.tex")
conch_recipe.tagneeded = false
conch_recipe.builder_tag = "bavbuilder"

-- The character select screen lines
STRINGS.CHARACTER_TITLES.bav = "Tomoe"
STRINGS.CHARACTER_NAMES.bav = "Tomoe"
STRINGS.CHARACTER_DESCRIPTIONS.bav = "*Close to him can reply sanity 靠近他可以回脑残\n*Click on him to resurrection 作崇他可以复活\n*Upgrade by eating monster lasagna吃怪物千层饼升级."
STRINGS.CHARACTER_QUOTES.bav = "\"Please count on me！请依靠我！\"" 

-- Custom speech strings
STRINGS.CHARACTERS.BAV = require "speech_bav"

-- The character's name as appears in-game 
STRINGS.NAMES.BAV = "Tomoe"

-- The default responses of examining the character
STRINGS.CHARACTERS.GENERIC.DESCRIBE.BAV = 
{
	GENERIC = "请依靠我",
	ATTACKER = "跟虫子一样弱埃",
	MURDERER = "可恶，可恶",
	REVIVER = "未来，令人期待",
	GHOST = "可以缔结神使的契约吗",
}


AddMinimapAtlas("images/map_icons/bav.xml")

-- Add mod character to mod character list. Also specify a gender. Possible genders are MALE, FEMALE, ROBOT, NEUTRAL, and PLURAL.
AddModCharacter("bav", "MALE")

