
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

		Asset("SCRIPT", "scripts/prefabs/player_common.lua"),

        Asset( "ANIM", "anim/bav.zip" ),
        Asset( "ANIM", "anim/ghost_bav_build.zip" ),
		
}
local prefabs = 
{
	"acefire",
	"minalinsky",
	"foxball",
	"coffee",
	"conch",
}

local start_inv = {
	-- Custom starting items
	"acefire",
	"foxball",	
}

local function lighton(inst, data) 
if TheWorld.state.isnight  then
	local light = inst.entity:AddLight()
	inst.Light:Enable(true)
	inst.Light:SetRadius(6)
	inst.Light:SetFalloff(.4)
	inst.Light:SetIntensity(.7)
	inst.Light:SetColour(255/255,20/255,20/255)
	
elseif TheWorld.state.isday then
	local light = inst.entity:AddLight()
	light:SetIntensity(0)
	light:SetRadius(0)
	light:SetFalloff(0)
	light:Enable(false)
	light:SetColour(180/255, 195/255, 150/255)
	
elseif TheWorld.state.isdusk then
	local light = inst.entity:AddLight()
	light:SetIntensity(.4)
	light:SetRadius(6)
	light:SetFalloff(.5)
	light:Enable(true)
	light:SetColour(180/255, 195/255, 150/255)
	end
end

local function Sparkle(inst)
    SpawnPrefab("firesplash_fx").entity:AddFollower():FollowSymbol(inst.GUID, "swap_body", 0, 0, 0)
    inst:DoTaskInTime(math.random(8, 10), Sparkle)
end

local function OnAttacked(inst, data)
    if data.attacker.components.health then
       data.attacker.components.health:DoDelta(-10)
    end
end

local function applyupgrades(inst)

	local max_upgrades = 30
	local upgrades = math.min(inst.level, max_upgrades)

	local hunger_percent = inst.components.hunger:GetPercent()
	local health_percent = inst.components.health:GetPercent()
	local sanity_percent = inst.components.sanity:GetPercent()

	inst.components.hunger.max = math.ceil (80 + upgrades * 4) --200
	inst.components.health.maxhealth = math.ceil (90 + upgrades * 2) --150
	inst.components.sanity.max = math.ceil (120 + upgrades * 6) --300
	
	inst.components.locomotor.walkspeed =  math.ceil (7 + upgrades / 7) --11
	inst.components.locomotor.runspeed = math.ceil (9 + upgrades / 6) --14
	
	inst.components.talker:Say("Level : ".. (inst.level))
	
	if inst.level >29 then
		inst.components.talker:Say("I am stronger!")
	end

	inst.components.hunger:SetPercent(hunger_percent)
	inst.components.health:SetPercent(health_percent)
	inst.components.sanity:SetPercent(sanity_percent)

end

local function oneat(inst, food)
	
	if food and food.components.edible and food.prefab == "monsterlasagna" then
		--give an upgrade!
		inst.level = inst.level + 1
		applyupgrades(inst)	
		inst.SoundEmitter:PlaySound("dontstarve/rain/thunder_close")

	end
end

local function onpreload(inst, data)
	if data then
		if data.level then
			inst.level = data.level
			applyupgrades(inst)
			--re-set these from the save data, because of load-order clipping issues
			if data.health and data.health.health then inst.components.health.currenthealth = data.health.health end
			if data.hunger and data.hunger.hunger then inst.components.hunger.current = data.hunger.hunger end
			if data.sanity and data.sanity.current then inst.components.sanity.current = data.sanity.current end
			inst.components.health:DoDelta(0)
			inst.components.hunger:DoDelta(0)
			inst.components.sanity:DoDelta(0)
		end
	end

end

local function onsave(inst, data)
	data.level = inst.level
	data.charge_time = inst.charge_time
end

-- This initializes for both clients and the host
local common_postinit = function(inst) 
	-- choose which sounds this character will play
	inst.soundsname = "wilson"
	
	inst:AddTag("bookbuilder")
	inst:AddTag("bavbuilder")

	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "bav.tex" )
end

-- This initializes for the host only
local master_postinit = function(inst)

	inst.level = 0
	inst.components.eater:SetOnEatFn(oneat)
	applyupgrades(inst)
	
	inst:AddComponent("reader")
	
	-- Stats
	inst.components.health:SetMaxHealth(90)
	inst.components.health:StartRegen(5, 10)
	inst.components.hunger:SetMax(80)
	inst.components.sanity:SetMax(120)
	inst.components.health.absorb = 0.30
	inst.components.locomotor.walkspeed = 7
	inst.components.locomotor.runspeed = 9
    inst.components.combat.damagemultiplier = 1
	
	inst.components.health.fire_damage_scale = 0	
	inst.components.sanity.night_drain_mult = 1
	inst.components.sanity.neg_aura_mult = 0
	inst.components.hunger.hungerrate = 1.2 * TUNING.WILSON_HUNGER_RATE
	
	inst:AddTag("birdwhisperer")
	
	inst:AddComponent("sanityaura")
    inst.components.sanityaura.aura = TUNING.SANITYAURA_SMALL
	
	inst:DoTaskInTime(math.random(8, 10), Sparkle)
	
	inst:ListenForEvent("sanitydelta", lighton)
	inst:ListenForEvent("attacked", OnAttacked)
	
	inst:ListenForEvent("equip", function()
	inst.AnimState:ClearOverrideSymbol("swap_hat")
	inst.AnimState:Show("hair")
	inst.AnimState:ClearOverrideSymbol("swap_body")
	end)
	
	local selfeater = inst.components.eater
    --inst.components.eater:SetDiet({ FOODGROUP.OMNI }, { FOODTYPE.MEAT })

	local old = selfeater.Eat
	function inst.components.eater:Eat(food)
		if selfeater:CanEat(food) then
			if food.components.edible.sanityvalue < 0 then
				food.components.edible.sanityvalue = 5
			end
			if food.components.edible.healthvalue < 0 then
				food.components.edible.healthvalue = 5
			end
		end
		return old(selfeater, food)
	end
	
	inst:AddComponent("hauntable")
    inst.components.hauntable:SetHauntValue(TUNING.HAUNT_INSTANT_REZ)
	
	inst:AddComponent("periodicspawner")
	inst.components.periodicspawner:SetPrefab("goldnugget")
	inst.components.periodicspawner:SetRandomTimes(480, 960)
	inst.components.periodicspawner:SetDensityInRange(-100, 5000000)
	inst.components.periodicspawner:SetMinimumSpacing(50000)
	inst.components.periodicspawner:Start()
	
	inst.OnSave = onsave
	inst.OnPreLoad = onpreload
	
end

return MakePlayerCharacter("bav", prefabs, assets, common_postinit, master_postinit, start_inv)
