local assets = {
	Asset("ANIM", "anim/foxball.zip"),
	Asset("ANIM", "anim/swap_foxball.zip"),

	Asset("ATLAS", "images/inventoryimages/foxball.xml"),
	Asset("IMAGE", "images/inventoryimages/foxball.tex")
}

local function pickup(inst, owner)
    if owner == nil or owner.components.inventory == nil then
        return
    end
    local x, y, z = owner.Transform:GetWorldPosition()
    local ents = TheSim:FindEntities(x, y, z, TUNING.ORANGEAMULET_RANGE, { "_inventoryitem" }, { "INLIMBO", "NOCLICK", "catchable", "fire" })
    for i, v in ipairs(ents) do
        if v.components.inventoryitem ~= nil and
            v.components.inventoryitem.canbepickedup and
            v.components.inventoryitem.cangoincontainer and
             not  v.components.inventoryitem:IsHeld() 
				and not v:HasTag("trap") 
				and not v:HasTag("light") and
            owner.components.inventory:CanAcceptCount(v, 1) > 0 then

            --Amulet will only ever pick up items one at a time. Even from stacks.
            local fx = SpawnPrefab("small_puff")
            fx.Transform:SetPosition(v.Transform:GetWorldPosition())
            fx.Transform:SetScale(.5, .5, .5)

            inst.components.finiteuses:Use(1)

            if v.components.stackable ~= nil then
                v = v.components.stackable:Get()
            end

            if v.components.trap ~= nil and v.components.trap:IsSprung() then
                v.components.trap:Harvest(owner)
            else
                owner.components.inventory:GiveItem(v)
            end
            return
        end
    end
end

local function OnEquip(inst, owner)
	owner.AnimState:OverrideSymbol("swap_object", "swap_foxball", "symbol")
	owner.AnimState:Show("ARM_carry")
	owner.AnimState:Hide("ARM_normal")
	inst.task = inst:DoPeriodicTask(TUNING.ORANGEAMULET_ICD, pickup, nil, owner)
end

local function OnUnequip(inst, owner)
	owner.AnimState:Hide("ARM_carry")
	owner.AnimState:Show("ARM_normal")
	if inst.task ~= nil then
        inst.task:Cancel()
        inst.task = nil
    end
end

local function fn()
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
	inst.entity:AddNetwork()
	
	MakeInventoryPhysics(inst)
	
	--inst.AnimState:SetBank(bank)
    --inst.AnimState:SetBuild(build)
	inst.AnimState:SetBank("foxball")
	inst.AnimState:SetBuild("foxball")
	inst.AnimState:PlayAnimation("idle") 
	
	inst:AddComponent("shaver")
	
	inst:AddTag("icebox_valid")
	inst:AddTag("sharp")
	
	inst.entity:SetPristine()
	
	if not TheWorld.ismastersim then
		return inst
	end
	
	inst:AddComponent("tool")
	inst.components.tool:SetAction(ACTIONS.MINE, 1)
	inst.components.tool:SetAction(ACTIONS.HAMMER, 0.4)
	inst.components.tool:SetAction(ACTIONS.CHOP, 5)
	inst.components.tool:SetAction(ACTIONS.DIG)
	
	inst:AddInherentAction(ACTIONS.TERRAFORM)
		
	inst:AddComponent("equippable")
	inst.components.equippable:SetOnEquip(OnEquip)
	inst.components.equippable:SetOnUnequip(OnUnequip)
	
	inst:AddComponent("inspectable")
	
	inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.imagename = "foxball"
	inst.components.inventoryitem.atlasname = "images/inventoryimages/foxball.xml"

	inst:AddComponent("terraformer")
	
	inst:AddComponent("finiteuses")
    inst.components.finiteuses:SetMaxUses(900)
    inst.components.finiteuses:SetUses(900)
    inst.components.finiteuses:SetOnFinished(inst.Remove)
	
	inst.components.finiteuses:SetConsumption(ACTIONS.CHOP, 1)
	inst.components.finiteuses:SetConsumption(ACTIONS.HAMMER, 1)
	inst.components.finiteuses:SetConsumption(ACTIONS.DIG, 1)
	inst.components.finiteuses:SetConsumption(ACTIONS.MINE, 1)
	inst.components.finiteuses:SetConsumption(ACTIONS.TERRAFORM, 1)
	
	inst:AddComponent("cooker")
	
	inst:AddComponent("tradable")
    inst.components.tradable.goldvalue = 6

	return inst
end

return Prefab("common/inventory/foxball", fn, assets)
